/********************************** (C) COPYRIGHT  *******************************
* File Name          : delay.c
* Author             : WCH
* Version            : V1.0.0
* Date               : 2020/02/19
* Description        : This file contains all the functions prototypes for Delay functions.
*******************************************************************************/
#include "delay.h"

static u8  fac_us=0;								   
static u16 fac_ms=0;	

/*******************************************************************************
* Function Name  : delay_init
* Description    : Initializes Delay Funcation.
* Input          : None
* Return         : None
*******************************************************************************/	
void delay_init()
{
	SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK_Div8);	
	fac_us=SystemCoreClock/8000000;				
	fac_ms=(u16)fac_us*1000;					 
}								    

/*******************************************************************************
* Function Name  : delay_us
* Description    : Microsecond Delay Time.
* Input          : nMicrosecond number.
*                     n * p_us < 0xFFFFFF
* Return         : None
*******************************************************************************/		
void delay_us(u32 nus)
{		
	u32 temp;	    	 
	SysTick->LOAD=nus*fac_us; 					 		 
	SysTick->VAL=0x00;        					
	SysTick->CTRL|=SysTick_CTRL_ENABLE_Msk ;	 
	do
	{
		temp=SysTick->CTRL;
	}while((temp&0x01)&&!(temp&(1<<16)));		 
	SysTick->CTRL&=~SysTick_CTRL_ENABLE_Msk;	
	SysTick->VAL =0X00;      					 
}

/*******************************************************************************
* Function Name  : delay_ms
* Description    : Millisecond Delay Time.
* Input          : nMillisecond number.
*                     n * p_ms < 0xFFFFFF
* Return         : None
*******************************************************************************/
void delay_ms(u16 nms)
{	 		  	  
	u32 temp;		   
	SysTick->LOAD=(u32)nms*fac_ms;				
	SysTick->VAL =0x00;							
	SysTick->CTRL|=SysTick_CTRL_ENABLE_Msk ;	
	do
	{
		temp=SysTick->CTRL;
	}while((temp&0x01)&&!(temp&(1<<16)));		 
	SysTick->CTRL&=~SysTick_CTRL_ENABLE_Msk;	
	SysTick->VAL =0X00;       					  	    
} 









































